@@ -4,3 +4,7 @@ FIREFOX = "firefox"
 
 # Configuration constants
 SUPPORTED_BROWSERS = {CHROME, FIREFOX}
+
+
+# Environ
+TRAVIS_ENV = "SYLENIUM_TRAVIS"
